******************************************************************************************************
********************************* Database importation ********************************************;

** Path to the file named : Data_JFE **;

	%LET path = C:\Users\sebsa\OneDrive\Documents\Recherche Reproductible\Reproductible;

* Import "Data_JFE" file *;

	PROC IMPORT DATAFILE="&path.\Data_JFE.xlsx"
				OUT=fusion
				DBMS=XLSX REPLACE;
	RUN;

* Log-transformation of mean_citations variable*;

	DATA fusion;
		SET fusion;
		log_citations = log(mean_citations + 1);
	RUN;	

********************************* PANEL A: Summary Statistics ***************************************;

ODS HTML FILE="Panel A and B.xls" ;

ODS NOPROCTITLE;

	* PANEL A - line 1 and 2 *;
	TITLE "PANEL A - line 1 and 2";

	PROC MEANS DATA=fusion MEAN STD MIN Q1 MEDIAN Q3 MAX N MAXDEC=3;
		VAR international top10;
	RUN;

	* PANEL A - line 3 and 4 *;
	TITLE "PANEL A - line 3 and 4";
	PROC MEANS DATA=fusion MEAN STD MIN Q1 MEDIAN Q3 MAX N MAXDEC=2;
		VAR mean_citations MEAN_SENIORITY;
		WHERE MISSING(MEAN_Seniority)=0; * Keep the same number of observations for all specifications *;
	RUN;

***************************** PANEL B: Logistic Regression *****************************;

**** (1) Citations, Seniority, International, Top 10 ****;

TITLE "Column 1";
TITLE2 "544 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	CLASS  TOP10(ref="0") international(ref="0")/ PARAM=REF;
	MODEL OPEN(EVENT="1") = TOP10 international log_citations MEAN_Seniority/ link=logit;
	WHERE MISSING(MEAN_Seniority)=0; * Keep the same number of observations for all specifications *;
RUN;

**** (2) Citations, Seniority, International, Tope 10, Time FE ****;

TITLE "Column 2";
TITLE2 "544 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	CLASS  TOP10(ref="0") international(ref="0") PUBLICATION_YEAR(ref="2010")/ PARAM=REF;
	MODEL OPEN(EVENT="1") = TOP10 international log_citations MEAN_Seniority PUBLICATION_YEAR/ link=logit;
	WHERE MISSING(MEAN_Seniority)=0; * Keep the same number of observations for all specifications *;
RUN;

**** (3) International, Top 10: Complete dataset ****;

TITLE "Column 3";
TITLE2 "1347 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	CLASS  TOP10(ref="0") international(ref="0")/ PARAM=REF;
	MODEL OPEN(EVENT="1") = TOP10 international / link=logit;
RUN;

**** (4) International, Top 10, Time FE: Complete dataset ****;

TITLE "Column 4";
TITLE2 "1347 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	CLASS  TOP10(ref="0") international(ref="0") PUBLICATION_YEAR(ref="2010")/ PARAM=REF;
	MODEL OPEN(EVENT="1") = TOP10 international PUBLICATION_YEAR/ link=logit;
RUN;

**** (5) Citations only ****;

TITLE "Column 5";
TITLE2 "544 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	WHERE MISSING(MEAN_Seniority)=0; * Keep the same number of observations for all specifications *;
	MODEL OPEN(EVENT="1") = log_citations / link=logit;
RUN;

**** (6) Citations + Time FE ****;

TITLE "Column 6";
TITLE2 "544 individuals";

PROC LOGISTIC DATA=fusion PLOTS=ROC;
	ODS SELECT ParameterEstimates;
	CLASS PUBLICATION_YEAR(ref="2010")/ PARAM=REF;
	MODEL OPEN(EVENT="1") = log_citations PUBLICATION_YEAR/ link=logit;
	WHERE MISSING(MEAN_Seniority)=0; * Keep the same number of observations for all specifications *;
RUN;

ODS HTML CLOSE;ODS HTML;
